@@ -2,7 +2,6 @@ import re
 from django.forms import Form
 from django import forms
 from django.core.exceptions import ValidationError
-from django.utils.translation import gettext_lazy as _
 
 regex_hexadecimal = re.compile("^#([A-Fa-f0-9]{6}|[A-Fa-f0-9]{3})$")
 
@@ -11,7 +10,7 @@ def is_valid_hexadecimal(value):
     is_hexadecimal = re.search(regex_hexadecimal, value)
     if not is_hexadecimal:
         raise ValidationError(
-            _('%(value)s is not a hexadecimal color'),
+            '%(value)s is not a hexadecimal color',
             params={'value': value},
         )
     return True
@@ -23,7 +22,7 @@ def is_valid_background_color(value):
     except ValidationError:
         if not value.startswith('radial-gradient(') and not value.startswith('linear-gradient('):
             raise ValidationError(
-                _('%(value)s is not a valid css property'),
+                '%(value)s is not a valid css property',
                 params={'value': value},
             )
 
@@ -42,20 +41,17 @@ class BackgroundColorFormField(forms.CharField):
 class ThemeLightForm(Form):
     theme_light_primary = HexFormField(
         required=False,
-        label=_('Color theme light primary'),
-        help_text=_('Hexadecimal color'),
+        label='Icon color',
         widget=forms.TextInput(attrs={'class': 'bg-light-0 dark:bg-dark-0 text-light-900 dark:text-dark-900'})
     )
     theme_light_secondary = HexFormField(
         required=False,
-        label=_('Color theme light secondary'),
-        help_text=_('Hexadecimal color'),
+        label='Icon hover color',
         widget=forms.TextInput(attrs={'class': 'bg-light-0 dark:bg-dark-0 text-light-900 dark:text-dark-900'})
     )
     theme_light_tertiary = HexFormField(
         required=False,
-        label=_('Color theme light tertiary'),
-        help_text=_('Hexadecimal color'),
+        label='Background color',
         widget=forms.TextInput(attrs={'class': 'bg-light-0 dark:bg-dark-0 text-light-900 dark:text-dark-900'})
     )
 
@@ -63,20 +59,17 @@ class ThemeLightForm(Form):
 class ThemeDarkForm(Form):
     theme_dark_primary = HexFormField(
         required=False,
-        label=_('Color theme dark primary'),
-        help_text=_('Hexadecimal color'),
+        label='Icon color',
         widget=forms.TextInput(attrs={'class': 'bg-light-0 dark:bg-dark-0 text-light-900 dark:text-dark-900'})
     )
     theme_dark_secondary = HexFormField(
         required=False,
-        label=_('Color theme dark secondary'),
-        help_text=_('Hexadecimal color'),
+        label='Icon hover color',
         widget=forms.TextInput(attrs={'class': 'bg-light-0 dark:bg-dark-0 text-light-900 dark:text-dark-900'})
     )
     theme_dark_tertiary = HexFormField(
         required=False,
-        label=_('Color theme dark tertiary'),
-        help_text=_('Hexadecimal color'),
+        label='Background color',
         widget=forms.TextInput(attrs={'class': 'bg-light-0 dark:bg-dark-0 text-light-900 dark:text-dark-900'})
     )
 
@@ -86,8 +79,8 @@ class ThemeDarkForm(Form):
 class ThemeLightAppForm(Form):
     theme_light_background_body = BackgroundColorFormField(
         required=False,
-        label=_('Color theme light background body'),
-        help_text=_('Hexadecimal color, linear-gradient, radial-gradient'),
+        label='Background color',
+        help_text='Hexadecimal color, linear-gradient, radial-gradient',
         widget=forms.TextInput(attrs={'class': 'bg-light-0 dark:bg-dark-0 text-light-900 dark:text-dark-900'})
     )
 
@@ -95,7 +88,7 @@ class ThemeLightAppForm(Form):
 class ThemeDarkAppForm(Form):
     theme_dark_background_body = BackgroundColorFormField(
         required=False,
-        label=_('Color theme dark background body'),
-        help_text=_('Hexadecimal color, linear-gradient, radial-gradient'),
+        label='Background color',
+        help_text='Hexadecimal color, linear-gradient, radial-gradient',
         widget=forms.TextInput(attrs={'class': 'bg-light-0 dark:bg-dark-0 text-light-900 dark:text-dark-900'})
     )
