@@ -5,11 +5,11 @@ import pkg_resources
 BASE_URL_CSS = "https://static.snoweb.io/snowebsvg/dist/css/"
 
 try:
-    #  Production part
+    #  Production part
     VERSION = pkg_resources.get_distribution("snowebsvg").version
 except pkg_resources.DistributionNotFound:
-    #  Develop part
-    BASE_DIR = os.environ['BASE_DIR']
+    #  Develop part
+    BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
     with open(os.path.join(BASE_DIR, 'package.json')) as package:
         data = json.load(package)
         VERSION = data['version']
